==> jc-1.4.0.tar.gz: ppg/atoms/SemanticAction.h <==
// public class ppg.atoms.SemanticAction

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ad102a5c5cfc3a0e ppg_atoms_GrammarPart
// @dep_class 5f7de1f7921420bf ppg_atoms_SemanticAction

// header file dependencies
// @dep_header ppg_atoms_GrammarPart

#include "ppg/atoms/GrammarPart.h"

#ifndef _JC_ppg_atoms_SemanticAction_H_
#define _JC_ppg_atoms_SemanticAction_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_ppg_util_CodeWriter$object;

// Typedefs
typedef struct _jc_ppg_atoms_SemanticAction$sub_refs	_jc_ppg_atoms_SemanticAction$sub_refs;
typedef struct _jc_ppg_atoms_SemanticAction$sub_nonrefs	_jc_ppg_atoms_SemanticAction$sub_nonrefs;
typedef struct _jc_ppg_atoms_SemanticAction$refs	_jc_ppg_atoms_SemanticAction$refs;
typedef struct _jc_ppg_atoms_SemanticAction$nonrefs	_jc_ppg_atoms_SemanticAction$nonrefs;
typedef struct _jc_ppg_atoms_SemanticAction$object	_jc_ppg_atoms_SemanticAction$object;

typedef const struct _jc_ppg_atoms_SemanticAction$vmethods	_jc_ppg_atoms_SemanticAction$vmethods;
typedef const struct _jc_ppg_atoms_SemanticAction$vtable	_jc_ppg_atoms_SemanticAction$vtable;
typedef const struct _jc_ppg_atoms_SemanticAction$vtype	_jc_ppg_atoms_SemanticAction$vtype;

// Constructors
extern void _jc_ppg_atoms_SemanticAction$method$_init$c31b894660454d13(_jc_env *, struct _jc_ppg_atoms_SemanticAction$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_ppg_atoms_SemanticAction$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_ppg_atoms_SemanticAction$object *);
extern struct _jc_java_lang_String$object *_jc_ppg_atoms_SemanticAction$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_ppg_atoms_SemanticAction$object *);
extern void _jc_ppg_atoms_SemanticAction$method$unparse$3d4a69bf2fda9799(_jc_env *, struct _jc_ppg_atoms_SemanticAction$object *, struct _jc_ppg_util_CodeWriter$object *);

// Virtual method descriptors
extern _jc_method _jc_ppg_atoms_SemanticAction$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_ppg_atoms_SemanticAction$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_ppg_atoms_SemanticAction$method_info$unparse$3d4a69bf2fda9799;

// Virtual methods structure
struct _jc_ppg_atoms_SemanticAction$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_ppg_atoms_SemanticAction$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_ppg_atoms_SemanticAction$object *);
	void	(*unparse$3d4a69bf2fda9799)(_jc_env *, struct _jc_ppg_atoms_SemanticAction$object *, struct _jc_ppg_util_CodeWriter$object *);
};

// Vtable
struct _jc_ppg_atoms_SemanticAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_atoms_GrammarPart$vmethods	ppg_atoms_GrammarPart;
	_jc_ppg_atoms_SemanticAction$vmethods	ppg_atoms_SemanticAction;
};

// Vtype
struct _jc_ppg_atoms_SemanticAction$vtype {
	_jc_type			type;
	_jc_ppg_atoms_SemanticAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_atoms_SemanticAction$sub_refs {
	struct _jc_java_lang_String$object	*action;
};

// Reference instance fields (object)
struct _jc_ppg_atoms_SemanticAction$refs {
    _jc_ppg_atoms_SemanticAction$sub_refs	ppg_atoms_SemanticAction;
    _jc_ppg_atoms_GrammarPart$sub_refs	ppg_atoms_GrammarPart;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_atoms_SemanticAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_atoms_SemanticAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_atoms_GrammarPart$sub_nonrefs	ppg_atoms_GrammarPart;
    _jc_ppg_atoms_SemanticAction$sub_nonrefs	ppg_atoms_SemanticAction;
};

// Object instance structure
struct _jc_ppg_atoms_SemanticAction$object {
	_jc_ppg_atoms_SemanticAction$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_atoms_SemanticAction$vtype	*vtype;
	_jc_ppg_atoms_SemanticAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_atoms_SemanticAction$vtype _jc_ppg_atoms_SemanticAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_atoms_SemanticAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_atoms_SemanticAction$class_object;

#endif	/* _JC_ppg_atoms_SemanticAction_H_ */

==> jc-1.4.6.tar.gz: ppg/atoms/SemanticAction.h <==
// public class ppg.atoms.SemanticAction

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ad102a5c5cfc3a0e ppg_atoms_GrammarPart
// @dep_class 5f7de1f7921420bf ppg_atoms_SemanticAction

// header file dependencies
// @dep_header ppg_atoms_GrammarPart

#include "ppg/atoms/GrammarPart.h"

#ifndef _JC_ppg_atoms_SemanticAction_H_
#define _JC_ppg_atoms_SemanticAction_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_ppg_util_CodeWriter$object;

// Typedefs
typedef struct _jc_ppg_atoms_SemanticAction$sub_refs	_jc_ppg_atoms_SemanticAction$sub_refs;
typedef struct _jc_ppg_atoms_SemanticAction$sub_nonrefs	_jc_ppg_atoms_SemanticAction$sub_nonrefs;
typedef struct _jc_ppg_atoms_SemanticAction$refs	_jc_ppg_atoms_SemanticAction$refs;
typedef struct _jc_ppg_atoms_SemanticAction$nonrefs	_jc_ppg_atoms_SemanticAction$nonrefs;
typedef struct _jc_ppg_atoms_SemanticAction$object	_jc_ppg_atoms_SemanticAction$object;

typedef const struct _jc_ppg_atoms_SemanticAction$vmethods	_jc_ppg_atoms_SemanticAction$vmethods;
typedef const struct _jc_ppg_atoms_SemanticAction$vtable	_jc_ppg_atoms_SemanticAction$vtable;
typedef const struct _jc_ppg_atoms_SemanticAction$vtype	_jc_ppg_atoms_SemanticAction$vtype;

// Constructors
extern void _jc_ppg_atoms_SemanticAction$method$_init$c31b894660454d13(_jc_env *, struct _jc_ppg_atoms_SemanticAction$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_ppg_atoms_SemanticAction$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_ppg_atoms_SemanticAction$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_ppg_atoms_SemanticAction$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_ppg_atoms_SemanticAction$object *) _JC_JCNI_ATTR;
extern void _jc_ppg_atoms_SemanticAction$method$unparse$3d4a69bf2fda9799(_jc_env *, struct _jc_ppg_atoms_SemanticAction$object *, struct _jc_ppg_util_CodeWriter$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_ppg_atoms_SemanticAction$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_ppg_atoms_SemanticAction$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_ppg_atoms_SemanticAction$method_info$unparse$3d4a69bf2fda9799;

// Virtual methods structure
struct _jc_ppg_atoms_SemanticAction$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_ppg_atoms_SemanticAction$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_ppg_atoms_SemanticAction$object *) _JC_JCNI_ATTR;
	void	(*unparse$3d4a69bf2fda9799)(_jc_env *, struct _jc_ppg_atoms_SemanticAction$object *, struct _jc_ppg_util_CodeWriter$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_ppg_atoms_SemanticAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_atoms_GrammarPart$vmethods	ppg_atoms_GrammarPart;
	_jc_ppg_atoms_SemanticAction$vmethods	ppg_atoms_SemanticAction;
};

// Vtype
struct _jc_ppg_atoms_SemanticAction$vtype {
	_jc_type			type;
	_jc_ppg_atoms_SemanticAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_atoms_SemanticAction$sub_refs {
	struct _jc_java_lang_String$object	*action;
};

// Reference instance fields (object)
struct _jc_ppg_atoms_SemanticAction$refs {
    _jc_ppg_atoms_SemanticAction$sub_refs	ppg_atoms_SemanticAction;
    _jc_ppg_atoms_GrammarPart$sub_refs	ppg_atoms_GrammarPart;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_atoms_SemanticAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_atoms_SemanticAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_atoms_GrammarPart$sub_nonrefs	ppg_atoms_GrammarPart;
    _jc_ppg_atoms_SemanticAction$sub_nonrefs	ppg_atoms_SemanticAction;
};

// Object instance structure
struct _jc_ppg_atoms_SemanticAction$object {
	_jc_ppg_atoms_SemanticAction$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_atoms_SemanticAction$vtype	*vtype;
	_jc_ppg_atoms_SemanticAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_atoms_SemanticAction$vtype _jc_ppg_atoms_SemanticAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_atoms_SemanticAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_atoms_SemanticAction$class_object;

#endif	/* _JC_ppg_atoms_SemanticAction_H_ */
